@@ -14,13 +14,12 @@ my $root = $FindBin::Bin;
 
 sub build
 {
-  my($class, $mb) = @_;
+  # $b isa ExtUtils::CBuilder
+  my(undef, $b, $extra_compiler_flags, $extra_linker_flags) = @_;
 
   my($header_time) = reverse sort map { (stat $_)[9] } bsd_glob "include/*.h";
   my $compile_count = 0;
   
-  my $b = $mb->cbuilder;
-  
   my @obj = map {
     my $filename = $_;
     my($source_time) = reverse sort ((stat $filename)[9], $header_time);
@@ -33,7 +32,7 @@ sub build
         include_dirs => [
           File::Spec->catdir($root, 'include'),
         ],
-        extra_compiler_flags => $mb->extra_compiler_flags,
+        extra_compiler_flags => $extra_compiler_flags,
       );
       $compile_count++;
     }
@@ -47,14 +46,25 @@ sub build
     my $dll = $b->link(
       lib_file           => $b->lib_file(File::Spec->catfile($root, 'libtest', $b->object_file('libtest.c'))),
       objects            => \@obj,
-      extra_linker_flags => $mb->extra_linker_flags,
+      extra_linker_flags => $extra_linker_flags,
     );
     
-    if($^O eq 'cygwin')
+    if($^O =~ /^(cygwin|msys)$/)
     {
       my $old = $dll;
       my $new = $dll;
-      $new =~ s{libtest.dll$}{cygtest-1.dll};
+      if($^O eq 'cygwin')
+      {
+        $new =~ s{libtest.dll$}{cygtest-1.dll};
+      }
+      elsif($^O eq 'msys')
+      {
+        $new =~ s{libtest.dll$}{msys-test-1.dll};
+      }
+      else
+      {
+        die "how?";
+      }
       move($old => $new) || die "unable to copy $old => $new $!";
     }
   }
